@@ -72,7 +72,7 @@ bool ClearThumbnailsAction::action()
 bool ClearRunCommandHistoryAction::action()
 {
     KConfig cfg(QStringLiteral("krunnerrc"));
-    KConfigGroup configGroup = cfg.group("General");
+    KConfigGroup configGroup = cfg.group(QStringLiteral("General"));
     configGroup.writeEntry("history", QStringList());
     configGroup.sync();
     return true;
@@ -92,7 +92,7 @@ bool ClearAllCookiesPoliciesAction::action()
 {
     // load the config file and section
     KConfig cfg(QStringLiteral("kcookiejarrc"));
-    KConfigGroup group = cfg.group("Cookie Policy");
+    KConfigGroup group = cfg.group(QStringLiteral("Cookie Policy"));
 
     qCDebug(SWEEPER_LOG) << "removing all saved cookie policies" ;
     group.deleteEntry("CookieDomainAdvice");
@@ -111,7 +111,7 @@ bool ClearSavedClipboardContentsAction::action()
 {
    if(!QDBusConnection::sessionBus().interface()->isServiceRegistered(QStringLiteral("org.kde.klipper"))) {
       auto c = new KConfig(QStringLiteral("klipperrc"), KConfig::NoGlobals);
-      KConfigGroup group(c, "General");
+      KConfigGroup group(c, QStringLiteral("General"));
       group.deleteEntry("ClipboardData");
       c->sync();
 
@@ -152,12 +152,7 @@ bool ClearRecentDocumentsAction::action()
                | Url::file();
 
    KAStats::forgetResources(query);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-   KRecentDocument::clear();
-   return KRecentDocument::recentDocuments().isEmpty();
-#else
    return true;
-#endif
 }
 
 bool ClearWebHistoryAction::action()
@@ -183,18 +178,16 @@ bool ClearFaviconsAction::action()
 {
    QDir favIconDir(QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation) + QLatin1Char('/') + QLatin1String( "favicons/" ));
    QStringList saveTheseFavicons;
-   KBookmarkManager* konqiBookmarkMgr;
 
    const QString path = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation)
       + QLatin1String("/konqueror/bookmarks.xml");
    QDir().mkpath(path);
-   konqiBookmarkMgr =
-      KBookmarkManager::managerForFile(path, QStringLiteral("konqueror"));
+   KBookmarkManager konqiBookmarkMgr(path);
    qCDebug(SWEEPER_LOG) << "saving the favicons that are in konqueror bookmarks"
-            << "opened konqueror bookmarks at " << konqiBookmarkMgr->path() ;
+            << "opened konqueror bookmarks at " << konqiBookmarkMgr.path() ;
 
    // get the entire slew of bookmarks
-   KBookmarkGroup konqiBookmarks = konqiBookmarkMgr->root();
+   KBookmarkGroup konqiBookmarks = konqiBookmarkMgr.root();
 
    // walk through the bookmarks, if they have a favicon we should keep it
    KBookmark bookmark = konqiBookmarks.first();
